pub struct TrackedClient {
pub runtime_id: String,
pub seen_any: bool,
pub products: i32,
}Fields
runtime_id: Stringseen_any: boolproducts: i32Implementations
Sourceimpl TrackedClient
impl TrackedClient
Sourcepub fn products(&self) -> ConfigSubscriptionProducts
pub fn products(&self) -> ConfigSubscriptionProducts
Returns the enum value of products, or the default if the field is set to an invalid enum value.
Sourcepub fn set_products(&mut self, value: ConfigSubscriptionProducts)
pub fn set_products(&mut self, value: ConfigSubscriptionProducts)
Sets products to the provided enum value.